# SIDE KICK

Side Kick is a simple, lightweight scheduler for Python. Assign a task to run by adding the ```@sidekick``` decorator 
and passing in the schedule for the task eg. 

```@sidekick(seconds=30)```

```@sidekick(minutes=45)```

```@sidekick(hours=6)```

```@sidekick(days=7)```

```@sidekick(minutes=45, hours=12)```


